@@ -5,14 +5,17 @@ from typing import Dict, Type, Union, Tuple, Callable
 from time import sleep
 import importlib
 import subprocess
-import sys, json
+import sys, json, os
 from bson import json_util
 
-def run_with_executable(function_name, executable=None, args=[], kwargs={}, stdout=None):
+def run_with_executable(function_name, executable=None, args=[], kwargs={}, stdout=None, modulePaths=[]):
   if executable is None:
     executable = sys.executable
 
-  data = {"function_name": function_name, "args": args, "kwargs": kwargs, "stdout": stdout}
+  if modulePaths is None:
+    modulePaths = []
+
+  data = {"function_name": function_name, "args": args, "kwargs": kwargs, "stdout": stdout, "modules": modulePaths + [os.getcwd(),]}
   result = subprocess.run([executable, "-c", executionCode], stdout=subprocess.PIPE, input=str.encode(json.dumps(data, default=json_util.default)))
   out = result.stdout.decode().split("\n")
   if len(out) > 0:
@@ -21,7 +24,7 @@ def run_with_executable(function_name, executable=None, args=[], kwargs={}, stdo
 
 class Worker:
 
-  def __init__(self, queues: Union[Tuple[Queue,...], Type[Queue]], channel: Union[Tuple[str,...], str]=None, heart_beat: int = 1, verbosity: str = "error", logger: Union[str, Callable] = None, executables: Dict = None, logFile: str = None) -> None:
+  def __init__(self, queues: Union[Tuple[Queue,...], Type[Queue]], channel: Union[Tuple[str,...], str]=None, heart_beat: int = 1, verbosity: str = "error", logger: Union[str, Callable] = None, executables: Dict = None, logFile: str = None, modulePaths=[]) -> None:
     
     if isinstance(queues, tuple) or isinstance(queues, list):
       self.queues = queues
@@ -46,6 +49,8 @@ class Worker:
     if not logFile is None:
       self.logFile = logFile
 
+    self.modulePaths = modulePaths
+
     if not executables is None and isinstance(executables, dict):
       self.executables = executables
     else:
@@ -118,7 +123,7 @@ class Worker:
             if channel in self.executables:
               executable = self.executables[channel]
 
-          output = run_with_executable(callback, args=args, kwargs=kwargs, executable=executable, stdout=self.logFile)
+          output = run_with_executable(callback, args=args, kwargs=kwargs, executable=executable, stdout=self.logFile, modulePaths=self.modulePaths)
 
           if not output is None:
             if "result" in output:
